# neuropredict

neuropredict is part of a broader intiative to develop easy, comprehensice and standardized predictive analysis - see [here](https://drive.google.com/open?id=0BxUb8ldwZEYJR3pCWFpyRUI1YUE) for an overview and the bigger picture idea.

[![travis](https://travis-ci.org/raamana/neuropredict.svg?branch=master)](https://travis-ci.org/raamana/neuropredict.svg?branch=master)
[![Code Health](https://landscape.io/github/raamana/neuropredict/master/landscape.svg?style=flat)](https://landscape.io/github/raamana/neuropredict/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/501e560b8a424562a1b8f7cd2f3cadfe)](https://www.codacy.com/app/raamana/neuropredict?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raamana/neuropredict&amp;utm_campaign=Badge_Grade)
[![PyPI version](https://badge.fury.io/py/neuropredict.svg)](https://badge.fury.io/py/neuropredict)
[![Python versions](https://img.shields.io/badge/python-3.5%2C%203.6-blue.svg)]

## Overview
![roleofneuropredict](docs/role.png)

|||
|--:|---|
| Docs: |  http://neuropredict.readthedocs.io |
| Contributing | http://contribution-guide-org.readthedocs.io/ |
